==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/BOILERTEXTENTRIESID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BOILERTEXTENTRIESID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BOILERTEXTENTRIESID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTNUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BOILERTEXTENTRIESID_Type", propOrder = {
    "functionid",
    "languageid",
    "boilertextnumber"
})
public class BOILERTEXTENTRIESID_Type {

    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;
    @XmlElement(name = "BOILERTEXTNUMBER")
    protected long boilertextnumber;

    /**
     * Obtient la valeur de la propriété functionid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Définit la valeur de la propriété functionid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Obtient la valeur de la propriété languageid.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Définit la valeur de la propriété languageid.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

    /**
     * Obtient la valeur de la propriété boilertextnumber.
     * 
     */
    public long getBOILERTEXTNUMBER() {
        return boilertextnumber;
    }

    /**
     * Définit la valeur de la propriété boilertextnumber.
     * 
     */
    public void setBOILERTEXTNUMBER(long value) {
        this.boilertextnumber = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/BOILERTEXTENTRIESID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BOILERTEXTENTRIESID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BOILERTEXTENTRIESID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTNUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BOILERTEXTENTRIESID_Type", propOrder = {
    "functionid",
    "languageid",
    "boilertextnumber"
})
public class BOILERTEXTENTRIESID_Type {

    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;
    @XmlElement(name = "BOILERTEXTNUMBER")
    protected long boilertextnumber;

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the languageid property.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Sets the value of the languageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

    /**
     * Gets the value of the boilertextnumber property.
     * 
     */
    public long getBOILERTEXTNUMBER() {
        return boilertextnumber;
    }

    /**
     * Sets the value of the boilertextnumber property.
     * 
     */
    public void setBOILERTEXTNUMBER(long value) {
        this.boilertextnumber = value;
    }

}
